# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_list_chat_message_read_with_metadata import ResponseWrapperListChatMessageReadWithMetadata  # noqa: E501

class TestResponseWrapperListChatMessageReadWithMetadata(unittest.TestCase):
    """ResponseWrapperListChatMessageReadWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListChatMessageReadWithMetadata:
        """Test ResponseWrapperListChatMessageReadWithMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListChatMessageReadWithMetadata`
        """
        model = ResponseWrapperListChatMessageReadWithMetadata()  # noqa: E501
        if include_optional:
            return ResponseWrapperListChatMessageReadWithMetadata(
                done = True,
                result = [
                    chat_server_connector.models.chat_message_read_with_metadata.ChatMessageReadWithMetadata(
                        text = '', 
                        file_id = '', 
                        id = 56, 
                        chat_message_type = 'TEXT', 
                        run_id = '', 
                        chat_id = 56, 
                        chat_member_id = 56, 
                        added_at = 56, 
                        attachments = [
                            chat_server_connector.models.chat_message_attachment_read_with_metadata.ChatMessageAttachmentReadWithMetadata(
                                file_id = '', 
                                attachment_type = 'IMAGE', 
                                id = 56, 
                                file_url = '', 
                                full_file_name = '', 
                                file_size = 56, 
                                file_extension = '', 
                                mime_type = '', )
                            ], 
                        chat_session = chat_server_connector.models.chat_session_get.ChatSessionGet(
                            id = 56, 
                            chat_id = 56, 
                            creator_id = 56, 
                            credentials = chat_server_connector.models.credentials.Credentials(), 
                            chat_session_type = 'TEXT', 
                            created_at = 56, 
                            ended_at = 56, 
                            last_activity_at = 56, ), 
                        feedback = chat_server_connector.models.feedback_read.FeedbackRead(
                            id = 56, 
                            chat_session_id = 56, 
                            chat_member_id = 56, 
                            type = 'BUG', 
                            text = '', 
                            priority = 56, 
                            added_at = 56, 
                            updated_at = 56, ), )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListChatMessageReadWithMetadata(
                done = True,
        )
        """

    def testResponseWrapperListChatMessageReadWithMetadata(self):
        """Test ResponseWrapperListChatMessageReadWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictInt
from chat_server_connector.models.chat_session_type import ChatSessionType

class ChatSessionGet(BaseModel):
    """
    ChatSessionGet
    """
    id: StrictInt = Field(...)
    chat_id: StrictInt = Field(...)
    creator_id: StrictInt = Field(...)
    credentials: Dict[str, Any] = Field(...)
    chat_session_type: ChatSessionType = Field(...)
    created_at: StrictInt = Field(...)
    ended_at: Optional[StrictInt] = None
    last_activity_at: StrictInt = Field(...)
    __properties = ["id", "chat_id", "creator_id", "credentials", "chat_session_type", "created_at", "ended_at", "last_activity_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatSessionGet:
        """Create an instance of ChatSessionGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatSessionGet:
        """Create an instance of ChatSessionGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatSessionGet.parse_obj(obj)

        _obj = ChatSessionGet.parse_obj({
            "id": obj.get("id"),
            "chat_id": obj.get("chat_id"),
            "creator_id": obj.get("creator_id"),
            "credentials": obj.get("credentials"),
            "chat_session_type": obj.get("chat_session_type"),
            "created_at": obj.get("created_at"),
            "ended_at": obj.get("ended_at"),
            "last_activity_at": obj.get("last_activity_at")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.goal_engagement_preset_get import GoalEngagementPresetGet  # noqa: E501

class TestGoalEngagementPresetGet(unittest.TestCase):
    """GoalEngagementPresetGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoalEngagementPresetGet:
        """Test GoalEngagementPresetGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoalEngagementPresetGet`
        """
        model = GoalEngagementPresetGet()  # noqa: E501
        if include_optional:
            return GoalEngagementPresetGet(
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                id = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
                order = 56
            )
        else:
            return GoalEngagementPresetGet(
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                id = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
                order = 56,
        )
        """

    def testGoalEngagementPresetGet(self):
        """Test GoalEngagementPresetGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
